* Container will require around 60GB of free disk space.
* Docker cache and running all models (without DLRM) will require ~600 GB free disk space.
* When you get into an interactive Docker mode, you can copy/paste CM commands generated by this GUI to benchmark different models.
